<html>
<head>
<STYLE>
a:link {text-decoration: none; color: #3399FF;}
a:visited {text-decoration: none; color: #3399FF;}
a:active {text-decoration: none; color: #3399FF;}
a:hover {text-decoration: none; color: red;}

input.submit  {border:0; color:#3399FF; font-family:helvetica; font-weight:bold;}
input.submit:hover  {border:0; color:red; font-family:helvetica; font-weight:bold;}

a:link img {border:0 none;}
a:hover hover img {position:relative; right:0px; top:0px; border:0; width:90px; margin:0 0 0 -90px}
a:hover hover2 img {position:relative; left:0px; top:0px; border:0; height:32px; margin:0 0 0 -240px}
a:hover hover3 img {position:relative; left:0px; top:0px; border:0; height:32px; margin:0 0 0 -160px}
a:hover hover4 img {position:relative; left:0px; top:0px; border:0; height:32px; margin:0 0 0 -80px}
a:hover hover5 img {position:static; left:0px; top:0px; border:0; height:100%; margin:0 0 0 -255px}
a:hover hover6 img {position:relative; left:0px; top:0px; border:0; height:100%; margin:0 0 0 -184px}
a:hover hover7 img {position:relative; left:0px; top:0px; border:0; height:100%; margin:0 0 0 -156px}
a:hover hover8 img {position:relative; left:0px; top:0px; border:0; height:100%; margin:0 0 0 -198px}

a:visited img {border:0 none;}

table.reports th, table.reports td
{
border: 0px;
border-collapse: collapse;
border-spacing: 5px;
font-size : 14px;
font-family : Verdana,Helvetica,Arial,sans-serif;
color : #000000;
}

body
{
font-family: Verdana,Helvetica,Arial,sans-serif;
}

</STYLE>

<title>Transient Classifier Daily Reports</title>

</head>

<BODY bgcolor="white">

<BR><BR>
<BR><BR>

<CENTER>
<BR><BR>
<FONT color="#000000" size='6'><B>PS1-QUB TRANSIENT SEARCH REPORTS</B></FONT>
<BR><BR>
<FONT color="#000000" size='2'>Click on each plot for high resolution image</FONT>
<BR><BR>
<BR><BR>
</CENTER>


<CENTER>

<DIV CLASS="hover">
<TABLE class="reports">

<TR>
<TD colspan="2"><BR><BR><CENTER><FONT color="#000000" size='3'><B>Cumulative Number of Transients Detected</B></FONT></CENTER><BR><BR></TD>
</TR>

<TR>
<TD><CENTER><FONT color="#000000" size='2'><B>Since Demo Month 2010</B></FONT></CENTER></TD>
</TR>

<TR>

<TD cellpadding="0"> <A href="../../site_media/images/reports/CumulativePromoted.png"><IMG src="../../site_media/images/reports/CumulativePromoted.png" height="600"  BORDER="0"/></A></TD>

</TR>
</TABLE>
</DIV>

<BR><BR>
<BR><BR>


<DIV CLASS="hover">
<TABLE class="reports">

<TR>
<TD colspan="3"><BR><BR><CENTER><FONT color="#000000" size='3'><B>Number of Transients Promoted per Day</B></FONT></CENTER><BR><BR></TD>
</TR>

<TR>
<TD><CENTER><FONT color="#000000" size='2'><B>Since Demo Month 2010</B></FONT></CENTER></TD>
<TD><CENTER><FONT color="#000000" size='2'><B>Past Six Months</B></FONT></CENTER></TD>
<TD><CENTER><FONT color="#000000" size='2'><B>Past Month</B></FONT></CENTER></TD>
</TR>

<TR>

<TD cellpadding="0"> <A href="../../site_media/images/reports/Promoted.png"><IMG src="../../site_media/images/reports/Promoted.png" height="280"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/PromotedSixMonths.png"><IMG src="../../site_media/images/reports/PromotedSixMonths.png" height="280"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/PromotedMonth.png"><IMG src="../../site_media/images/reports/PromotedMonth.png" height="280"  BORDER="0"/></A></TD>

</TR>

<TR>
<TD colspan="3"><BR><BR><CENTER><FONT color="#000000" size='3'><B>Number of Objects Promoted and Dumped per Day</B></FONT></CENTER><BR><BR></TD>
</TR>

<TR>
<TD><CENTER><FONT color="#000000" size='2'><B>Since Demo Month 2010</B></FONT></CENTER></TD>
<TD><CENTER><FONT color="#000000" size='2'><B>Past Six Months</B></FONT></CENTER></TD>
<TD><CENTER><FONT color="#000000" size='2'><B>Past Month</B></FONT></CENTER></TD>
</TR>

<TR>

<TD cellpadding="0"> <A href="../../site_media/images/reports/PromotedDumped.png"><IMG src="../../site_media/images/reports/PromotedDumped.png" height="280"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/PromotedDumpedSixMonths.png"><IMG src="../../site_media/images/reports/PromotedDumpedSixMonths.png" height="280"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/PromotedDumpedMonth.png"><IMG src="../../site_media/images/reports/PromotedDumpedMonth.png" height="280"  BORDER="0"/></A></TD>

</TR>

<TR>
<TD colspan="3"><BR><BR><CENTER><FONT color="#000000" size='3'><B>Number of Diff Detections Ingested and Rejected per Day</B></FONT></CENTER><BR><BR></TD>
</TR>

<TR>
<TD><CENTER><FONT color="#000000" size='2'><B>Since Demo Month 2010</B></FONT></CENTER></TD>
<TD><CENTER><FONT color="#000000" size='2'><B>Past Six Months</B></FONT></CENTER></TD>
<TD><CENTER><FONT color="#000000" size='2'><B>Past Month</B></FONT></CENTER></TD>
</TR>

<TR>

<TD cellpadding="0"> <A href="../../site_media/images/reports/IngestedRejected.png"><IMG src="../../site_media/images/reports/IngestedRejected.png" height="280"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/IngestedRejectedSixMonths.png"><IMG src="../../site_media/images/reports/IngestedRejectedSixMonths.png" height="280"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/IngestedRejectedMonth.png"><IMG src="../../site_media/images/reports/IngestedRejectedMonth.png" height="280"  BORDER="0"/></A></TD>

</TR>

<TR>
<TD colspan="3"><BR><BR><CENTER><FONT color="#000000" size='3'><B>Number of Diff Detections Ingested per Observation Date</B></FONT></CENTER><BR><BR></TD>
</TR>

<TR>
<TD><CENTER><FONT color="#000000" size='2'><B>Since Demo Month 2010</B></FONT></CENTER></TD>
<TD><CENTER><FONT color="#000000" size='2'><B>Past Six Months</B></FONT></CENTER></TD>
<TD><CENTER><FONT color="#000000" size='2'><B>Past Month</B></FONT></CENTER></TD>
</TR>

<TR>

<TD cellpadding="0"> <A href="../../site_media/images/reports/InsertedMJD.png"><IMG src="../../site_media/images/reports/InsertedMJD.png" height="280"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/InsertedMJDSixMonths.png"><IMG src="../../site_media/images/reports/InsertedMJDSixMonths.png" height="280"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/InsertedMJDMonth.png"><IMG src="../../site_media/images/reports/InsertedMJDMonth.png" height="280"  BORDER="0"/></A></TD>

</TR>
</TABLE>
</DIV>

<BR><BR>
<BR><BR>

<DIV CLASS="hover">
<TABLE class="reports">

<TR>
<TD colspan="2"><BR><BR><CENTER><FONT color="#000000" size='3'><B>Number of Diff Detections per Lunation</B></FONT></CENTER><BR><BR></TD>
</TR>

<TR>
<TD><CENTER><FONT color="#000000" size='2'><B>Transients Promoted</B></FONT></CENTER></TD>
<TD><CENTER><FONT color="#000000" size='2'><B>Diff Detections Ingested</B></FONT></CENTER></TD>
</TR>

<TR>

<TD cellpadding="0"> <A href="../../site_media/images/reports/PromotedLunation.png"><IMG src="../../site_media/images/reports/PromotedLunation.png" height="280"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/InsertedLunation.png"><IMG src="../../site_media/images/reports/InsertedLunation.png" height="280"  BORDER="0"/></A></TD>

</TR>
</TABLE>
</DIV>

<BR><BR>
<BR><BR>

<DIV CLASS="hover">
<TABLE class="reports">

<TR>
<TD colspan="2"><BR><BR><CENTER><FONT color="#000000" size='3'><B>Position of Transients Promoted in each Medium Deep Field</B></FONT></CENTER><BR><BR></TD>
</TR>

<TR>

<TD cellpadding="0"> <A href="../../site_media/images/reports/MD01.png"><IMG src="../../site_media/images/reports/MD01.png" height="600"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/MD02.png"><IMG src="../../site_media/images/reports/MD02.png" height="600"  BORDER="0"/></A></TD>

</TR>
<TR>

<TD cellpadding="0"> <A href="../../site_media/images/reports/MD03.png"><IMG src="../../site_media/images/reports/MD03.png" height="600"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/MD04.png"><IMG src="../../site_media/images/reports/MD04.png" height="600"  BORDER="0"/></A></TD>

</TR>
<TR>

<TD cellpadding="0"> <A href="../../site_media/images/reports/MD05.png"><IMG src="../../site_media/images/reports/MD05.png" height="600"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/MD06.png"><IMG src="../../site_media/images/reports/MD06.png" height="600"  BORDER="0"/></A></TD>

</TR>
<TR>

<TD cellpadding="0"> <A href="../../site_media/images/reports/MD07.png"><IMG src="../../site_media/images/reports/MD07.png" height="600"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/MD08.png"><IMG src="../../site_media/images/reports/MD08.png" height="600"  BORDER="0"/></A></TD>

</TR>
<TR>

<TD cellpadding="0"> <A href="../../site_media/images/reports/MD09.png"><IMG src="../../site_media/images/reports/MD09.png" height="600"  BORDER="0"/></A></TD>
<TD cellpadding="0"> <A href="../../site_media/images/reports/MD10.png"><IMG src="../../site_media/images/reports/MD10.png" height="600"  BORDER="0"/></A></TD>

</TR>
</TABLE>
</DIV>

</CENTER>

<br><br><br>

</html>

