{% extends "base_bootstrap_login.html" %}
{% block title %}Login{% endblock %}
{% block content %}


<div class="container-fluid h-100">
  <div class="row justify-content-center align-items-center h-100">
    <div class="col-lg-4 col-md-6 col-sm-12">


  {% if form.errors %}
    <p class="error">Sorry, that's not a valid username or password</p>
  {% endif %}

  <div class="form-group">

  <form action="{% url "auth" %}" method="post" id="loginform">{% csrf_token %}
  {% if request.GET.next %}
  <input type="hidden" name="next" value="{{ request.GET.next }}" />
  {% endif %}
  

  <table class="forms">
      {{ form.as_table }}
  </table>

  <button class="btn btn-outline-info my-2 my-sm-0" type="submit" value="login">Login</button>

  </form>

  </div>

  <p>Can't login? Contact Ken Smith at QUB</p>

    </div>
  </div>
</div>

{% endblock %}
