-- DANGER - THIS WILL REMOVE ALL DATA FROM THE DATABASE!!!!
truncate table atlas_diff_objects;
truncate table atlas_diff_detections;
truncate table atlas_detectionsddc;
truncate table atlas_metadata;
truncate table atlas_metadataddc;
truncate table atlas_forced_photometry;
truncate table atlas_stacked_forced_photometry;
truncate table atlas_diff_logs;
truncate table atlas_diff_moments;
truncate table atlas_diff_subcell_logs;
truncate table atlas_diff_subcells;
truncate table tcs_cross_matches;
truncate table tcs_cross_matches_external;
truncate table tcs_cmf_metadata;
truncate table tcs_transient_objects;
truncate table tcs_transient_reobservations;
truncate table tcs_images;
truncate table tcs_image_groups;
truncate table tcs_postage_stamp_images;
truncate table tcs_postage_stamp_requests;
truncate table tcs_classification_history;
truncate table tcs_zoo_requests;
truncate table tcs_forced_photometry;
truncate table tcs_latest_object_stats;
truncate table tcs_processing_status;
truncate table tcs_object_comments;
truncate table sherlock_crossmatches;
truncate table sherlock_classifications;
truncate table tcs_gravity_events;
truncate table tcs_gravity_event_annotations;
