{% extends "base_bootstrap_login.html" %}

{% block title %}Server Error{% endblock %}

{% block content %}

<div class="container-fluid h-100">
  <div class="row justify-content-center align-items-center h-100">
    <div class="col-lg-4 col-md-6 col-sm-12">

    <h1 class="text-center">Error 500: Server Error</h1>

    <p class="text-center">Apologies - something went wrong with the server. Try coming back later.</p>

    </div>
  </div>
</div>
{% endblock %}
