{% extends "base_bootstrap.html" %}

{% block title %}ATLAS Static Transients{% endblock %}

{% block content %}

<div class="container-fluid">
  <div class="row">

    <div class="col-lg-12 col-md-12 col-sm-12">

<h3>ATLAS Static Transients</h3>

<p>The <a href="http://fallingstar.com">ATLAS</a> project is a pair of 0.5m f/2.0 Schmidt telescopes situated on Mauna Loa and Haleakala in Hawaii (Tonry 2011, PASP, 123, 58). Each telescope is equipped with an STA-1600 10.5x10.5k CCD with 1.86 arcsec pixels giving a FOV of 5.4x5.4 degrees. The first ATLAS unit has been installed on Haleakala and is robotically surveying the sky, covering up to 18,000 square degrees per night with exposure times of 30s. The current observing pattern uses dithered quads across a sky survey area of 4500 square degrees per night. The design sensitivity is around m ~ 20 AB mag in two broad filters (cyan and orange). The sky coverage will triple as overheads are reduced and when the second unit is installed on Mauna Loa in 2016. The primary mission for ATLAS is to act as an asteroid impact early warning system and find near earth objects, but in the course of the ATLAS sky survey it will find a wealth of stationary transients and variables. We intend to make the transient discoveries public with a minimum of delay. Discoveries are made through a custom built difference imaging pipeline and deep reference sky frames, cross-matched against known star, galaxy and transient catalogues.
</p>

    </div>
  </div>
</div>

{% endblock %}
