update tcs_transient_objects set observation_status = 'AGN' where observation_status = 'AGN / QSO' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'Impostor-SN' where observation_status = 'impostor' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN I' where observation_status = 'I' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Ia' where observation_status = 'Ia' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Ia-91bg-like' where observation_status = 'Ia-91bg-like' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Ia-91T-like' where observation_status = 'Ia-91T-like' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Ia-CSM' where observation_status = 'Ia-CSM' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Ia-pec' where observation_status = 'Ia pec' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Iax[02cx-like]' where observation_status = 'Iax[02cx-like]' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Ib' where observation_status = 'Ib' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Ib-Ca-rich' where observation_status = 'Ib-Ca-rich' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Ib-pec' where observation_status = 'Ib-pec' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Ib/c' where observation_status = 'Ibc' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Ibn' where observation_status = 'Ibn' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Ic' where observation_status = 'Ic' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Ic-BL' where observation_status = 'Ic-BL' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN Ic-pec' where observation_status = 'Ic pec' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN II' where observation_status = 'II' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN II-pec' where observation_status = 'II pec' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN IIb' where observation_status = 'IIb' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN IIL' where observation_status = 'II-L' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN IIn' where observation_status = 'IIn' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN IIn-pec' where observation_status = 'IIn-pec' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'SN IIP' where observation_status = 'II-P' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
update tcs_transient_objects set observation_status = 'Varstar' where observation_status = 'stellar' and detection_list_id is not null and detection_list_id in (0,1,2,3,4,5,6,7,8);
