{% extends "base_bootstrap.html" %}

{% load render_table from django_tables2 %}

{% block title %}{% if listHeader %}{{listHeader}}{% else %}Followup List{% endif %}{% endblock %}

{% block content %}

<div class="container-fluid">
  <div class="row">
    <div class="col-lg-12 col-md-12 col-sm-12">


{% if listHeader %}
   <h3>{{ listHeader }}</h3>
{% else %}
   <h3>Object List</h3>
{% endif %}

<h4>({{table.rows|length}})</h4>

{% if listHeader %}
  {% if list_id >= 0 and list_id < 9 and table.rows|length > 0 %}
<form id="classify_form" action="" method="post">{% csrf_token %}
  {% endif %}
{% endif %}

      {% if table.rows|length > 0 %}
      <div class="table-responsive table-body table-condensed">
        {% render_table table %}
      </div>
      {% endif %}

{% if listHeader %}
  {% if list_id >= 0 and list_id < 9 and table.rows|length > 0 %}
<input type="submit" value="Classify Objects" name="classify" /></p>
  {% endif %}
</form>
{% endif %}

    </div>
  </div>
</div>

{% endblock %}
