{% extends "admin/base.html" %}
{% load i18n %}

{% block title %}{{ title }} | {% trans 'Pan-STARRS Transient Classification Server site admin' %}{% endblock %}

{% block branding %}
<h1 id="site-name">{% trans 'Pan-STARRS Transient Classification Server administration' %}</h1>
{% endblock %}

{% block nav-global %}{% endblock %}
